==> haskell-csv-0.1.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: csv
version: 0.1.2
id: csv-0.1.2-JHiDO18E4reI6zYI6iizmR
key: csv-0.1.2-JHiDO18E4reI6zYI6iizmR
license: MIT
copyright: Jaap Weel, 2007
maintainer: Jaap Weel <weel@ugcs.caltech.edu>
synopsis: CSV loader and dumper
description:
    CSV loader and dumper
    .
    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.
category: Text
author: Jaap Weel <weel@ugcs.caltech.edu>
exposed: True
indefinite: False
exposed-modules:
    Text.CSV
abi: d778e46fa612889b3c689a57f9f2e321
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/csv-0.1.2
hs-libraries: HScsv-0.1.2-JHiDO18E4reI6zYI6iizmR
depends:
    base-4.10.1.0 filepath-1.4.1.2 parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=5b8a6db8c81629fde3a12212030372e3
haddock-interfaces: /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html: /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-csv-0.1.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: csv
version: 0.1.2
id: csv-0.1.2-2drtEiDLXdL83OHUGecst6
key: csv-0.1.2-2drtEiDLXdL83OHUGecst6
license: MIT
copyright: Jaap Weel, 2007
maintainer: Jaap Weel <weel@ugcs.caltech.edu>
synopsis: CSV loader and dumper
description:
    CSV loader and dumper
    .
    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.
category: Text
author: Jaap Weel <weel@ugcs.caltech.edu>
exposed: True
indefinite: False
exposed-modules:
    Text.CSV
abi: 8bfe9af80572930cd237ce5870be5f68
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/csv-0.1.2
hs-libraries: HScsv-0.1.2-2drtEiDLXdL83OHUGecst6
depends:
    base-4.10.1.0 filepath-1.4.1.2
    parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
haddock-interfaces: /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html: /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
